Index: /trunk/psLib/src/astro/psCoord.c
===================================================================
--- /trunk/psLib/src/astro/psCoord.c	(revision 3333)
+++ /trunk/psLib/src/astro/psCoord.c	(revision 3334)
@@ -10,6 +10,6 @@
 *  @author GLG, MHPCC
 *
-*  @version $Revision: 1.54 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2005-02-25 20:52:28 $
+*  @version $Revision: 1.55 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2005-02-25 22:28:42 $
 *
 *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -379,6 +379,6 @@
 }
 
-// XXX: This is bug 245: alphaP swaps with phiP from psSphereTransformGalaticToICRS()
-psSphereTransform* psSphereTransformICRSToGalatic(void)
+// XXX: This is bug 245: alphaP swaps with phiP from psSphereTransformGalacticToICRS()
+psSphereTransform* psSphereTransformICRSToGalactic(void)
 {
     psF64 alphaP = DEG_TO_RAD(32.93192);
@@ -389,5 +389,5 @@
 }
 
-psSphereTransform* psSphereTransformGalaticToICRS(void)
+psSphereTransform* psSphereTransformGalacticToICRS(void)
 {
     psF64 alphaP = DEG_TO_RAD(282.85948);
Index: /trunk/psLib/src/astro/psCoord.h
===================================================================
--- /trunk/psLib/src/astro/psCoord.h	(revision 3333)
+++ /trunk/psLib/src/astro/psCoord.h	(revision 3334)
@@ -10,6 +10,6 @@
 *  @author GLG, MHPCC
 *
-*  @version $Revision: 1.26 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2005-02-17 19:26:23 $
+*  @version $Revision: 1.27 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2005-02-25 22:29:19 $
 *
 *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -292,15 +292,15 @@
 );
 
 /** Creates the appropriate transform for converting from ICRS to Galatic
  *  coordinate systems.
  *
  */
-psSphereTransform* psSphereTransformICRSToGalatic(void);
-
-/** Creates the appropriate transform for converting from Galatic to ICRS
+psSphereTransform* psSphereTransformICRSToGalactic(void);
+
+/** Creates the appropriate transform for converting from Galactic to ICRS
  *  coordinate systems.
  *
  */
-psSphereTransform* psSphereTransformGalaticToICRS(void);
+psSphereTransform* psSphereTransformGalacticToICRS(void);
 
 /** Allocates memory for a psProjection structure
@@ -292,15 +292,15 @@
 );
 
-/** Creates the appropriate transform for converting from ICRS to Galatic
+/** Creates the appropriate transform for converting from ICRS to Galactic
  *  coordinate systems.
  *
Index: /trunk/psLib/src/astronomy/psCoord.c
===================================================================
--- /trunk/psLib/src/astronomy/psCoord.c	(revision 3333)
+++ /trunk/psLib/src/astronomy/psCoord.c	(revision 3334)
@@ -10,6 +10,6 @@
 *  @author GLG, MHPCC
 *
-*  @version $Revision: 1.54 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2005-02-25 20:52:28 $
+*  @version $Revision: 1.55 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2005-02-25 22:28:42 $
 *
 *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -379,6 +379,6 @@
 }
 
-// XXX: This is bug 245: alphaP swaps with phiP from psSphereTransformGalaticToICRS()
-psSphereTransform* psSphereTransformICRSToGalatic(void)
+// XXX: This is bug 245: alphaP swaps with phiP from psSphereTransformGalacticToICRS()
+psSphereTransform* psSphereTransformICRSToGalactic(void)
 {
     psF64 alphaP = DEG_TO_RAD(32.93192);
@@ -389,5 +389,5 @@
 }
 
-psSphereTransform* psSphereTransformGalaticToICRS(void)
+psSphereTransform* psSphereTransformGalacticToICRS(void)
 {
     psF64 alphaP = DEG_TO_RAD(282.85948);
Index: /trunk/psLib/src/astronomy/psCoord.h
===================================================================
--- /trunk/psLib/src/astronomy/psCoord.h	(revision 3333)
+++ /trunk/psLib/src/astronomy/psCoord.h	(revision 3334)
@@ -10,6 +10,6 @@
 *  @author GLG, MHPCC
 *
-*  @version $Revision: 1.26 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2005-02-17 19:26:23 $
+*  @version $Revision: 1.27 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2005-02-25 22:29:19 $
 *
 *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -292,15 +292,15 @@
 );
 
 /** Creates the appropriate transform for converting from ICRS to Galatic
  *  coordinate systems.
  *
  */
-psSphereTransform* psSphereTransformICRSToGalatic(void);
-
-/** Creates the appropriate transform for converting from Galatic to ICRS
+psSphereTransform* psSphereTransformICRSToGalactic(void);
+
+/** Creates the appropriate transform for converting from Galactic to ICRS
  *  coordinate systems.
  *
  */
-psSphereTransform* psSphereTransformGalaticToICRS(void);
+psSphereTransform* psSphereTransformGalacticToICRS(void);
 
 /** Allocates memory for a psProjection structure
@@ -292,15 +292,15 @@
 );
 
-/** Creates the appropriate transform for converting from ICRS to Galatic
+/** Creates the appropriate transform for converting from ICRS to Galactic
  *  coordinate systems.
  *
